@@ -25,13 +25,16 @@ from typing import (
 
 from requests.structures import CaseInsensitiveDict
 
-try:
-    from smart_open import open  # Migration for smart_open 1.8.1 # type: ignore
-except ImportError:
-    from smart_open import smart_open as open  # type: ignore
-except ImportError:
-    pass
-from tabulate import tabulate  # type: ignore
+try:  # pragma: no cover
+    # This import works for smart_open>=1.8.1
+    from smart_open import open
+except ImportError as error:  # pragma: no cover
+    try:
+        # This import works for smart_open<1.8.1
+        from smart_open import smart_open as open
+    except ImportError as error:
+        pass
+from tabulate import tabulate
 from terminaltables import SingleTable
 
 from .util import maybe_render_markdown
@@ -269,7 +272,8 @@ class Sample(CaseInsensitiveDict):
     """
 
     _valid_index_key_pattern = re.compile(r'index\d?')
-    _valid_index_value_pattern = re.compile(r'^[ACGTN]*$')
+    # https://kb.10xgenomics.com/hc/en-us/articles/218168503-What-oligos-are-in-my-sample-index-
+    _valid_index_value_pattern = re.compile(r'^[ACGTN]*$|^SI-[ACGTN]{2}-[A-H]\d+$')
 
     def __init__(
         self, data: Optional[Mapping] = None, **kwargs: Mapping
@@ -529,11 +533,10 @@ class SampleSheet(object):
                 continue
 
             # [<Other>] - keys in first column and values in second column.
-            else:
-                key, value, *_ = line
+            elif len(line) >= 2:
+                key, value = (line[0], line[1])
                 section: Section = getattr(self, section_name)
                 section[key] = value
-                continue
 
     def add_sample(self, sample: Sample) -> None:
         """Add a :class:`Sample` to this :class:`SampleSheet`.
